@@ -983,6 +983,8 @@ class LoadParser : public CatalogParser
         Language GetSpecifiedMsgidLanguage()
         {
             auto x_srclang = m_catalog.m_header.GetHeader("X-Source-Language");
+            if (x_srclang.empty())
+                x_srclang = m_catalog.m_header.GetHeader("X-Loco-Source-Locale");
             if (!x_srclang.empty())
             {
                 auto parsed = Language::TryParse(str::to_utf8(x_srclang));
@@ -1378,7 +1380,7 @@ void Catalog::FixupCommonIssues()
         // Auto-fill default plural form if it is missing:
         if (m_header.Lang.IsValid() && HasPluralItems())
         {
-            pluralForms = m_header.Lang.DefaultPluralFormsExpr();
+            pluralForms = m_header.Lang.DefaultPluralFormsExpr().str();
             if (!pluralForms.empty())
                 m_header.SetHeader("Plural-Forms", pluralForms);
         }
@@ -2025,17 +2027,6 @@ bool Catalog::FixDuplicateItems()
 namespace
 {
 
-wxString MaskForType(const char *extensions, const wxString& description, bool showExt = true)
-{
-    (void)showExt;
-#ifdef __WXMSW__
-    if (showExt)
-        return wxString::Format("%s (%s)|%s", description, extensions, extensions);
-    else
-#endif
-        return wxString::Format("%s|%s", description, extensions);
-}
-
 wxString MaskForType(Catalog::Type t)
 {
     switch (t)
@@ -2101,7 +2092,9 @@ Catalog::ValidationResults Catalog::DoValidate(const wxString& po_file)
         i->ClearIssue();
 
     res.errors = (int)err.size();
-    res.warnings = QAChecker::GetFor(*this)->Check(*this);
+
+    if (Config::ShowWarnings())
+        res.warnings = QAChecker::GetFor(*this)->Check(*this);
 
     for ( GettextErrors::const_iterator i = err.begin(); i != err.end(); ++i )
     {
@@ -2426,7 +2419,7 @@ bool Catalog::HasPluralItems() const
 void Catalog::SetLanguage(Language lang)
 {
     m_header.Lang = lang;
-    m_header.SetHeaderNotEmpty("Plural-Forms", lang.DefaultPluralFormsExpr());
+    m_header.SetHeaderNotEmpty("Plural-Forms", lang.DefaultPluralFormsExpr().str());
 }
 
 void Catalog::GetStatistics(int *all, int *fuzzy, int *badtokens,
