@@ -310,8 +310,7 @@ wxString PoeditApp::GetAppBuildNumber() const
 
 bool PoeditApp::IsBetaVersion() const
 {
-    wxString v = GetAppVersion();
-    return v.Contains("beta") || v.Contains("rc");
+    return false;
 }
 
 bool PoeditApp::CheckForBetaUpdates() const
@@ -635,7 +634,7 @@ void PoeditApp::OpenFiles(const wxArrayString& names, int lineno)
         if (n.EndsWith(".mo") || n.EndsWith(".gmo"))
         {
             wxMessageDialog dlg(nullptr,
-                                _("MO files can’t be directly edited in Poedit."),
+                                _(L"MO files can’t be directly edited in Poedit."),
                                 _("Error opening file"),
                                 wxOK);
             dlg.SetExtendedMessage(_("Please open and edit the corresponding PO file instead. When you save it, the MO file will be updated as well."));
@@ -725,9 +724,10 @@ bool PoeditApp::OnCmdLineParsed(wxCmdLineParser& parser)
         {
             wxString poeditURI;
             if (parser.Found(CL_HANDLE_POEDIT_URI, &poeditURI))
+            {
                 client.HandleCustomURI(poeditURI);
-
-            if (parser.GetParamCount() == 0)
+            }
+            else if (parser.GetParamCount() == 0)
             {
                 client.Activate();
             }
