@@ -197,9 +197,14 @@ public:
             {
                 // as a special case, allow translating ... (3 dots) as … (ellipsis)
             }
-            else if (u_hasBinaryProperty(s_last, UCHAR_QUOTATION_MARK) && u_hasBinaryProperty(t_last, UCHAR_QUOTATION_MARK))
+            else if (u_hasBinaryProperty(s_last, UCHAR_QUOTATION_MARK) || u_hasBinaryProperty(t_last, UCHAR_QUOTATION_MARK))
             {
-                // don't check for correct quotes for now, accept any quotations marks as equal
+                // quoted fragments can move around, e.g., so ignore quotes in reporting:
+                //      >> Invalid value for ‘{fieldName}’​ field
+                //      >> Valor inválido para el campo ‘{fieldName}’
+                // TODO: count quote characters to check if used correctly in translation; don't check position
+                // (don't check for correct quotes for now, accept any quotations marks as equal)
+
             }
             else if (IsEquivalent(s_last, t_last))
             {
@@ -262,6 +267,12 @@ private:
                     break;
             }
         }
+        else if (m_lang == "el")
+        {
+            // In Greek, questions end with ';' and not '?'.
+            if (src == '?')
+                return trans == ';';
+        }
 
         return false;
     }
